import express, {Request, Response, Router} from "express";
import {sendError} from "@utils/error";
import { authenticate } from "@middlewares/auth";
import authRoutes from "./auth";
import accountRoutes from "./account";
import projectRoutes from "./project";
import keyRoutes from "./key";

const app: Router = express.Router();

// Middlewares that don't require authentication
app.use("/auth", authRoutes);
app.use("/user", accountRoutes);


// Middlewares that require authentication
app.use(authenticate);

app.use("/project", projectRoutes);
app.use("/key", keyRoutes);

app.use("*", (req: Request, res: Response) => sendError(res, 404, 0, "The provided route could not be found"));

export default app;